import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleBand, scaleLinear, max } from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/tejasri280/e09ee2b41cc7ce575336cbb980ca0381/raw/e1b1bad0345a81aaf403cbc8a02c651d51b7285d/JioMusic.csv';
const width = 960;
const height = 500;
const margin = {
  top: 20,
  right: 20,
  bottom: 50,
  left: 200,
};

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = (d) => {
      d.basic_Cost = +d['basic_Cost'];
      return d;
    };
    csv(csvUrl, row).then((data) => {
      setData(data.slice(0, 12));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight =
    height - margin.top - margin.bottom - 100;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleBand()
    .domain(data.map((d) => d.name))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, (d) => d.duration)])
    .range([0, innerWidth]);

  const colorScale = scaleLinear()
    .domain([0, max(data, (d) => d.duration)])
    .range(['rgb(0, 0, 255)', 'rgb(255, 0, 0)']); // Blue to Red gradient

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
        {xScale.ticks().map((tickValue) => (
          <g
            key={tickValue}
            transform={`translate(${xScale(tickValue)},0)`}
          >
            <line y2={innerHeight} stroke="Blue" />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".70em"
              y={innerHeight + 3}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map((tickValue) => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map((d) => (
          <rect
            key={d.name}
            x={0}
            y={yScale(d.name)}
            width={xScale(d.duration)}
            height={yScale.bandwidth()}
            fill={colorScale(d.duration)}
          />
        ))}
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
